/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seata.config.processor;

import org.apache.seata.common.loader.LoadLevel;
import org.apache.seata.common.util.MapUtil;
import org.yaml.snakeyaml.LoaderOptions;
import org.yaml.snakeyaml.Yaml;
import org.yaml.snakeyaml.constructor.SafeConstructor;

import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Properties;

/**
 * The Yaml Processor.
 *
 */
@LoadLevel(name = "yaml")
public class ProcessorYaml implements Processor {

    @Override
    public Properties processor(String config) {
        Properties properties = new Properties();
        Map<String, Object> configMap = MapUtil.asMap(new Yaml(new SafeConstructor(new LoaderOptions())).load(config));
        Map<String, String> stringConfigMap = new LinkedHashMap<>();
        MapUtil.getFlattenedMap(configMap).forEach((k, v) -> {
            stringConfigMap.put(k, v == null ? null : String.valueOf(v));
        });
        properties.putAll(stringConfigMap);
        return properties;
    }
}
